<?xml version="1.0" encoding="UTF-8"?>

<!--
 ********************************************************************
 * IBM Developer for z/OS
 * IBM z/OS Automated Unit Testing Framework (zUnit)
 * AZUZ2S30
 *
 * This XSL stylesheet can be used to convert a version 3.0.x.x 
 * zUnit test runner result file (*.bzures) for a SonarQube execution
 * report file (*.xml).  
 *
 * TODO: Edit the line after TODO comment according to the
 *       environment
 *  e.x.
 *  <xsl:value-of select="concat('utests/', @moduleName, '.pli')"/>
 *
 * @since   14.2.1.0
 * @version 14.2.1.0
 ******************************************************************** 
-->

<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xalan="http://xml.apache.org/xslt"
    xmlns:res="http://www.ibm.com/zUnit/3.0.0.0/TestRunner"
    version="1.0">
    
    <xsl:output method="xml" encoding="UTF-8" indent="yes" 
                standalone="yes" xalan:indent-amount="4"/>

    <xsl:template match="/">
        <xsl:apply-templates select="res:RunnerResult"/>
    </xsl:template>

    <xsl:template match="res:RunnerResult">
        <testExecutions version="1">
            <xsl:apply-templates select="res:testCase"/>
        </testExecutions>
    </xsl:template>

    <xsl:template match="res:testCase">
        <file>
            <xsl:attribute name="path">
                <!-- TODO: Edit according to the environment -->
                <xsl:value-of select="concat('tests/', @moduleName, '.cbl')"/>
            </xsl:attribute>
            <xsl:apply-templates select="res:test"/>
            <xsl:if test="res:failure">
                <system-out>                
                    <xsl:value-of select="res:failure/@message"/>
                </system-out>
            </xsl:if>
            <xsl:if test="res:compareFailure">
                <system-out>                
                    <xsl:value-of select="res:failure/@message"/>
                </system-out>
            </xsl:if>
            <xsl:if test="res:error">
                <system-err>                
                    <xsl:value-of select="res:error/@message"/>
                </system-err>
            </xsl:if>
        </file>
    </xsl:template>

    <xsl:template match="res:test">
        <xsl:if test="not(@dummy) or @dummy = 'false'">
            <testCase>
                <xsl:attribute name="name">
                    <xsl:value-of select="@name"/>
                </xsl:attribute>
                <xsl:attribute name="duration">
                    <xsl:value-of select="@elapsedTime * 1000"/>
                </xsl:attribute>
                <xsl:apply-templates select="res:error"/>
                <xsl:apply-templates select="res:failure"/>
            </testCase>
        </xsl:if>
    </xsl:template>

    <xsl:template match="res:failure">
        <failure>
            <xsl:if test="@message">
                <xsl:attribute name="message">
                    <xsl:value-of select="@message"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:attribute name="type">
                <xsl:value-of 
    select="concat(@componentCode, @messageNumber, @messageSeverity)"/>
            </xsl:attribute>
            <xsl:if test="@message">
                <xsl:text>&#x0a;</xsl:text>                      
                <xsl:value-of select="@message"/>
            </xsl:if>
            <xsl:text>&#x0a;</xsl:text>            
            <xsl:apply-templates select="res:traceback"/>            
        </failure> 
    </xsl:template>

    <xsl:template match="res:error">
        <error>
            <xsl:if test="@message">
                <xsl:attribute name="message">
                    <xsl:value-of select="@message"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:attribute name="type">
                <xsl:value-of 
    select="concat(@componentCode, @messageNumber, @messageSeverity)"/>
            </xsl:attribute>
            <xsl:if test="@message">
                <xsl:text>&#x0a;</xsl:text>                      
                <xsl:value-of select="@message"/>
            </xsl:if>
            <xsl:text>&#x0a;</xsl:text>                                  
            <xsl:apply-templates select="res:traceback"/>            
        </error>
    </xsl:template>
    
    <xsl:template match="res:traceback">
        <xsl:if test="@entry">
            <xsl:value-of select="@entry"/>
        </xsl:if>    
        <xsl:if test="@entryName">
            <xsl:value-of select="@entryName"/>
        </xsl:if>    
        <xsl:if test="@entryName">
            <xsl:value-of select="@programUnitName"/>
        </xsl:if>    
        <xsl:if test="@statementID">
            <xsl:text>(</xsl:text>
            <xsl:value-of select="@statementID"/>
            <xsl:text>)</xsl:text>
        </xsl:if>    
        <xsl:text>&#x0a;</xsl:text>        
    </xsl:template>    

</xsl:stylesheet>